'use strict'

exports.__esModule = true
exports.default = exports.useDebounce = exports.useDebounceCallback = void 0

var _react = require('react')

var _utils = require('@render-props/utils')

const useDebounceCallback = (fn, wait = 100, leading = false) => {
  const timeout = (0, _react.useRef)(null)
  const next = (0, _react.useCallback)(
    (args, this_) => {
      timeout.current = null
      leading !== true && fn.apply(this_, args)
    },
    [fn]
  )

  function _ref() {
    return (
      timeout.current !== null &&
      (0, _utils.clearRequestTimeout)(timeout.current)
    )
  }

  return (0, _react.useCallback)(
    function() {
      const this_ = this

      if (timeout.current === null && leading === true) {
        fn.apply(this_, arguments)
      } else if (timeout.current !== null) {
        ;(0, _utils.clearRequestTimeout)(timeout.current)
      }

      timeout.current = (0, _utils.requestTimeout)(
        () => next(arguments, this_),
        wait
      )
      return _ref
    },
    [next, wait]
  )
}

exports.useDebounceCallback = useDebounceCallback

const useDebounce = (initialState, wait, leading) => {
  const [state, setState] = (0, _react.useState)(initialState)
  return [state, useDebounceCallback(setState, wait, leading)]
}

exports.useDebounce = useDebounce
var _default = useDebounce
exports.default = _default
